@@ -1,5 +1,5 @@
 print <<"EOF";
-style ibm
+style ter-uni-framebuf
 size 16
 layout ${CYR_KBD}
 options ${CYR_OPTION}
