@@ -2,6 +2,6 @@
 This file is executed by sh(1) for login shells.
 Setup the Macedonian locale and Cyrillic on console.
 END
-This file is executed by sh(1) for login shells.
-Setup the Macedonian locale and Cyrillic on console.
+     sh(1)    .
+      .
 END
