@@ -185,11 +185,13 @@ sub initialize()
 	} elsif ($Sub::IM_DEFAULT eq "Anthy") {
 		if (!$IM_EXIST{"Anthy"}) {
 			&Sub::addlist("anthy");
+			&Sub::addlist("uim-anthy");
 			&Sub::addlist("uim-xim");
 		}
 	} elsif ($Sub::IM_DEFAULT eq "PRIME") {
 		if (!$IM_EXIST{"PRIME"}) {
 			&Sub::addlist("prime");
+			&Sub::addlist("uim-prime");
 			&Sub::addlist("uim-xim");
 		}
 	}
