@@ -22,6 +22,7 @@ sub initialize()
 {
 	&Sub::addlist("locales");
 	&Sub::addlist("fonty");
+	&Sub::addlist("util-linux-locales");
 
 # manpages
 	&Sub::addlist("manpages-pl");
@@ -64,6 +65,13 @@ sub initialize()
 		&Sub::addlist("mozilla-locale-pl");
 		&Sub::addlist("myspell-pl");
 	}
+	if (&Sub::isinstalled("mozilla-firefox")) {
+		&Sub::addlist("mozilla-firefox-locale-pl");
+	}
+	if (&Sub::isinstalled("mozilla-thunderbird")) {
+		&Sub::addlist("mozilla-thunderbird-locale-pl");
+		&Sub::addlist("myspell-pl");
+	}
 # kde
         if (&Sub::isinstalled("kdebase")) {
                 &Sub::addlist("kde-i18n-pl");
@@ -77,7 +85,6 @@ sub initialize()
                 &Sub::addlist("xutils");
 	}
 
-
 # x-fonts
 	if (&Sub::isinstalled("xserver-.*")) {
 		&Sub::addlist("xfonts-biznet-base");
@@ -198,14 +205,14 @@ sub convcode($$)
   "wylogowac i zalogowac ponownie\n.\n".
   "   Prosze przejrzec kazdy zmieniony plik konfiguracyjny i sprawdzic\n".
   "ustawienia. Jezeli nie sa one zgodne z Twoimi oczekiwaniami, \n".
-  "popraw je lub dodaj wlasne nadpisujace ustawienie po linii 'language-env end'.\n".
+  "popraw je lub dodaj wlasne, nadpisujace ustawienie po linii 'language-env end'.\n".
   "   Szczegolowe informacje mozna znalezc w /usr/share/doc/language-env/README.* .\n\000" .
 # msgstr2 (in Native Character Set)
   "   Zapisano ustawienia.  Aby je uaktywni, naley si\n".
   "wylogowa i zalogowa ponownie\n.\n".
   "   Prosz przejrze kady zmieniony plik konfiguracyjny i sprawdzi\n".
   "ustawienia. Jeeli nie s one zgodne z Twoimi oczekiwaniami, \n".
-  "popraw je lub dodaj wasne nadpisujce ustawienie po linii 'language-env end'.\n".
+  "popraw je lub dodaj wasne, nadpisujce ustawienie po linii 'language-env end'.\n".
   "   Szczegowe informacje mona znale w /usr/share/doc/language-env/README.* .\n" ,
 
 # msgid
